==> range-iterator-2.0.4.tgz: package/mod.js <==
/**
 * Resolve code point of the character.
 * @access private
 * @param {string} parameterName Name of the parameter.
 * @param {string} value Character.
 * @returns {number} Code point of the character.
 */
function resolveCharacterCodePoint(parameterName, value) {
    try {
        const valueSplit = [...value];
        if (valueSplit.length !== 1) {
            throw undefined;
        }
        const characterCodePoint = value.codePointAt(0);
        if (typeof characterCodePoint === "undefined") {
            throw undefined;
        }
        return characterCodePoint;
    }
    catch {
        throw new RangeError(`\`${value}\` (parameter \`${parameterName}\`) is not a character which is in code point range 0 ~ 1114111!`);
    }
}
/**
 * Looper of the range iterator.
 * @access private
 * @template {RangeIteratorAcceptType} T
 * @param {RangeIteratorLooperParameters<T>} param0 Parameters.
 * @returns {Generator<T>}
 */
function* rangeLooper({ end, endExclusive, resultIsString, start, step }) {
    const isReverse = start > end;
    //@ts-ignore All of the types are compatible.
    for (let current = start; isReverse ? (current >= end) : (current <= end); current += isReverse ? -step : step) {
        if (!(endExclusive && current === end)) {
            yield (resultIsString ? String.fromCodePoint(current) : current);
        }
    }
}
export function rangeIterator(start, end, param2) {
    const options = (typeof param2 === "bigint" ||
        typeof param2 === "number") ? { step: param2 } : (param2 ?? {});
    const optionsEndExclusive = options.endExclusive ?? options.exclusiveEnd ?? false;
    if (typeof start === "bigint" && typeof end === "bigint") {
        if (typeof options.step !== "undefined") {
            if (!(options.step > 0n)) {
                throw new RangeError(`\`${options.step}\` (parameter \`options.step\`) is not a bigint which is > 0!`);
            }
        }
        return rangeLooper({
            end,
            endExclusive: optionsEndExclusive,
            resultIsString: false,
            start,
            step: options.step ?? 1n
        });
    }
    let resultIsString = false;
    let startAsNumber;
    let endAsNumber;
    if (typeof start === "number" && typeof end === "number") {
        startAsNumber = start;
        endAsNumber = end;
    }
    else if (typeof start === "string" && typeof end === "string") {
        resultIsString = true;
        startAsNumber = resolveCharacterCodePoint("start", start);
        endAsNumber = resolveCharacterCodePoint("end", end);
    }
    else {
        throw new TypeError(`Parameters \`start\` and \`end\` are not bigints, numbers, or strings (character)!`);
    }
    if (typeof options.step !== "undefined") {
        if (!(options.step > 0)) {
            throw new RangeError(`\`${options.step}\` (parameter \`options.step\`) is not a number which is > 0!`);
        }
    }
    return rangeLooper({
        end: endAsNumber,
        endExclusive: optionsEndExclusive,
        resultIsString,
        start: startAsNumber,
        step: options.step ?? 1
    });
}
export default rangeIterator;

==> range-iterator-2.0.5.tgz: package/mod.js <==
function resolveCharacterCodePoint(parameterName, item) {
    try {
        const itemSplit = [...item];
        if (itemSplit.length !== 1) {
            throw undefined;
        }
        const result = item.codePointAt(0);
        if (typeof result === "undefined") {
            throw undefined;
        }
        return result;
    }
    catch {
        throw new RangeError(`\`${item}\` (parameter \`${parameterName}\`) is not a character which is in code point range 0 ~ 1114111!`);
    }
}
function* rangeLooper({ end, endExclusive, resultIsString, start, step }) {
    const isReverse = start > end;
    //@ts-ignore All of the types are compatible.
    for (let current = start; isReverse ? (current >= end) : (current <= end); current += isReverse ? -step : step) {
        if (!(endExclusive && current === end)) {
            yield (resultIsString ? String.fromCodePoint(current) : current);
        }
    }
}
export function rangeIterator(start, end, param2) {
    const options = (typeof param2 === "bigint" ||
        typeof param2 === "number") ? { step: param2 } : (param2 ?? {});
    const optionsEndExclusive = options.endExclusive ?? options.exclusiveEnd ?? false;
    if (typeof start === "bigint" && typeof end === "bigint") {
        if (typeof options.step !== "undefined") {
            if (!(typeof options.step === "bigint" && options.step > 0n)) {
                throw new RangeError(`\`${options.step}\` (parameter \`options.step\`) is not a bigint which is > 0!`);
            }
        }
        return rangeLooper({
            end,
            endExclusive: optionsEndExclusive,
            resultIsString: false,
            start,
            step: options.step ?? 1n
        });
    }
    let resultIsString;
    let startAsNumber;
    let endAsNumber;
    if (typeof start === "number" && typeof end === "number") {
        resultIsString = false;
        startAsNumber = start;
        endAsNumber = end;
    }
    else if (typeof start === "string" && typeof end === "string") {
        resultIsString = true;
        startAsNumber = resolveCharacterCodePoint("start", start);
        endAsNumber = resolveCharacterCodePoint("end", end);
    }
    else {
        throw new TypeError(`Parameters \`start\` and \`end\` are not bigints, numbers, or strings (character)!`);
    }
    if (typeof options.step !== "undefined") {
        if (!(typeof options.step === "number" && options.step > 0)) {
            throw new RangeError(`\`${options.step}\` (parameter \`options.step\`) is not a number which is > 0!`);
        }
    }
    return rangeLooper({
        end: endAsNumber,
        endExclusive: optionsEndExclusive,
        resultIsString,
        start: startAsNumber,
        step: options.step ?? 1
    });
}
export default rangeIterator;
